Module backends

Module backends 

implementations of backends

Structs

BackendsIter
An iterator over the variants of Backends
FreeWebNovel
An implementation of backend for FreeWebNovel
LibRead
A backend using libread. Honestly i don’t know why i bothered with it, since i’m under the impression that most chapters redirect to FreeWebNovel.
LightNovelWorld
Backend for lightnovelworld.com
RoyalRoad
A Backend implementation for RoyalRoad

Enums

BackendError
An error that may be returned when the backend encounters an error
Backends
Enum listing all available backends. A new backend may be constructed using Backends::new.

Traits

Backend
Must be implemented by each backend.